;; Generated package description from spacious-padding.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "spacious-padding" "0.6.1.0.20250429.100228" "Increase the padding/spacing of frames and windows" '((emacs "28.1")) :commit "cd33d70f6cd9d8f3a2f6f7831711c8230d21649d" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("convenience" "focus" "writing" "presentation") :url "https://github.com/protesilaos/spacious-padding")
